/*
 * kinectserver - a program that send data from the Kinect sensor to connected clients.
 * Copyright (c) 2011, University of Kent.
 * Contact: Neil Brown, nccb@kent.ac.uk
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef LOG_H
#define LOG_H

#include <sstream>
#include <iostream>
#include <boost/thread/mutex.hpp>

#define LOG_OP(T) inline Logger& operator<<(T x) \
  { mutex.lock(); stream << x; mutex.unlock(); return *this; }

class Logger : public boost::noncopyable
{
 private:
  std::stringstream stream;
  boost::mutex mutex;
 public:
  LOG_OP(const char*)
  LOG_OP(short)
  LOG_OP(unsigned short)
  LOG_OP(int)
  LOG_OP(unsigned int)
  LOG_OP(double)

  inline void printStdout()
  {
    std::cout << getText() << std::endl;
  }

  inline std::string getText()
  {
    std::string r;
    mutex.lock();
    r = stream.str();
    mutex.unlock();
    return r;
  }
};

typedef Logger& Log;

#endif //LOG_H
