/*
 * kinectserver - a program that send data from the Kinect sensor to connected clients.
 * Copyright (c) 2011, University of Kent.
 * Contact: Neil Brown, nccb@kent.ac.uk
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef MYTIME_H
#define MYTIME_H

#ifdef WIN32
#include <windows.h>

class Time
{
  DWORD t;
  inline Time(DWORD _t) : t(_t) {}
public:
  inline Time() {}
  inline void setCurrentTime() { t = GetTickCount(); }
  inline bool operator<(const Time& x) const { return t < x.t; }
  inline Time operator-(const Time& x) const { return Time(t - x.t); }
  inline double getSeconds() const { return (double)t / 1000.0; }
  static Time minutes(int mins) { return Time(mins * 60 * 1000); }
};
#else
#include <sys/time.h>

class Time
{
  timeval t;
public:
  inline Time() {}
  inline void setCurrentTime() { gettimeofday(&t, NULL); }
  inline bool operator<(const Time& x) const { return timercmp(&t, &(x.t), <); }
  inline Time operator-(const Time& x) const { Time r; timersub(&t, &(x.t), &(r.t)); return r; }
  inline double getSeconds() const { return (t.tv_sec*1000000.0 + t.tv_usec) / 1000000.0; }
  static Time minutes(int mins) { Time r; r.t.tv_usec = 0; r.t.tv_sec = mins * 60; return r; }
};
#endif //WIN32




#endif //MYTIME_H
