/*
 * kinectserver - a program that send data from the Kinect sensor to connected clients.
 * Copyright (c) 2011, University of Kent.
 * Contact: Neil Brown, nccb@kent.ac.uk
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SERVER_H
#define SERVER_H

#include "mytime.h"
#include "log.h"

#include <boost/smart_ptr.hpp>

class KinectInterfaceFactory;
class ServerImpl;

class Server : public boost::noncopyable
{
 private:
  boost::intrusive_ptr<ServerImpl> impl;
 public:
  Server(Log log);
  ~Server();

  // string (if not empty) says where to store image feed
  // bool param is true for network, false for localhost
  bool init(KinectInterfaceFactory*, std::string, bool);
  bool start();
  void stop();
  /// false if there is a problem
  /// if idle is not NULL, and there haven't been any clients for longer than that amount of time,
  /// processing will be stopped (and false will be returned).
  bool process(const Time* idle, bool attemptRestartIfClients, int maxRetries = 10);
};

#endif //SERVER_H
